@@ -14,8 +14,6 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-import sys
-from math import sqrt, sin, cos, pi
 import xml.etree.ElementTree as ET
 from datetime import datetime, timedelta
 from math import pi, sin, cos, acos
@@ -40,7 +38,7 @@ class GpxWarning(Exception):
 class WptModel(QtCore.QAbstractTableModel):
   def __init__(self, parent=None):
     super(WptModel, self).__init__(parent)
-    self.fields = [self.tr('Name'), self.tr('Latitude'), self.tr('Longitude'), self.tr('Altitude'),
+    self.fields = [self.tr('Name'), self.tr('Latitude'), self.tr('Longitude'), self.tr('Elevation'),
                    self.tr('Distance'), self.tr('Time'), self.tr('Time difference'), self.tr('Time in days')]
     self.resetModel()
     self.pix = QPixmap(16, 16)
